==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { PathGeometry } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { RectUtil } from "igniteui-react-core";
import { PolyLineSegment } from "igniteui-react-core";
import { PathFigure } from "igniteui-react-core";
import { PathFigureCollection } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { boxArray$1, arrayShallowClone } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeries, _super);
    function ScatterLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterLineSeries.$;
        _this.rq = new ScatterFrame();
        _this.rs = new ScatterFrame();
        _this.ro = new ScatterFrame();
        var a = function (b, c, d) {
            var e = _this.ci.indexOf(b.a);
            if (e == -1 || e == 0) {
                return b;
            }
            var f = _this.ci.item(e - 1);
            var g;
            if (!((function () { var h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                return b;
            }
            return g;
        };
        _this.rq.o = a;
        _this.rs.o = a;
        _this.ro.o = a;
        return _this;
    }
    ScatterLineSeries.prototype.get_dx = function () {
        return true;
    };
    ScatterLineSeries.prototype.bv = function () {
        return new ScatterLineSeriesView(this);
    };
    ScatterLineSeries.prototype.er = function (a, b) {
        if (this.p3(a, b)) {
            return true;
        }
        if (this.ue(a, b)) {
            return true;
        }
        return false;
    };
    ScatterLineSeries.prototype.ue = function (a, b) {
        var c = this.by;
        var d = c.dg;
        return this.es(a, b, d.ak);
    };
    ScatterLineSeries.prototype.tc = function (a, b) {
        var _this = this;
        _super.prototype.tc.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.bv;
        var d = b.bu;
        var e = this.getEffectiveViewport1(b);
        var f = this.gk * this.gk;
        var g = 0;
        if (this.r0 != null) {
            g = this.r0.count;
        }
        if (this.r1 != null) {
            g = Math.min(this.r1.count, g);
        }
        var h = new ScalerParams(0, c, d, this.rk.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.rk.e, e);
            $ret.b = _this.f4();
            return $ret;
        })());
        var j = arrayShallowClone(this.r0.asArray());
        var k = arrayShallowClone(this.r1.asArray());
        this.xAxis.hi(boxArray$1(j), 0, j.length, h);
        this.yAxis.hi(boxArray$1(k), 0, k.length, i);
        var l = d.top - 10;
        var m = d.bottom + 10;
        var n = d.left - 10;
        var o = d.right + 10;
        var p = ((function () {
            var $ret = new Clipper(1, n, m, o, l, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var q = 0; q < g;) {
            var r = q;
            ++q;
            if (g > this.sl) {
                while (q < g) {
                    var s = j[q] - j[r];
                    var t = k[q] - k[r];
                    var u = s * s + t * t;
                    if (u >= f) {
                        break;
                    }
                    ++q;
                }
                p.j(this.ul(j, k, r, q - 1));
            }
            else {
                var v = new OwnedPoint();
                v.c = { $type: Point_$type, x: j[r], y: k[r] };
                v.a = this.ci.item(r);
                if (!a.u.containsKey(v.a)) {
                    a.u.addItem(v.a, v);
                }
            }
        }
        if (g > this.sl) {
            p.i = null;
        }
    };
    ScatterLineSeries.prototype.ul = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a[c], y: b[c] };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a[h];
            f += b[h];
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterLineSeries.prototype.get_r8 = function () {
        return true;
    };
    ScatterLineSeries.prototype.tn = function (a, b) {
        b.c4(false);
        _super.prototype.tn.call(this, a, b);
        var c = this.getEffectiveViewport1(b);
        var d = new Rect(0, b.bu.left, b.bu.top, b.bu.width, b.bu.height);
        d = RectUtil.t(d, this.fn, this.fn);
        this.tg(a, new Clipper(0, d, false));
        var e = typeCast(ScatterLineSeriesView.$, b);
        this.rx.ax(this, this.sd(), runOn(this, this.q8));
        var f = false;
        var g = this.rx.b;
        if (g != null) {
            f = true;
        }
        if (f) {
            this.s8(-1, this.r0.count, b.q);
        }
        this.rx.ad(e.dg, true, false, true, false);
        this.uj(e.dg, a.m.count, function (h) { return a.m._inner[h].x; }, function (h) { return a.m._inner[h].y; }, this.ud, this.gk);
    };
    ScatterLineSeries.prototype.uj = function (a, b, c, d, e, f) {
        var g = new PathGeometry();
        a.ak = g;
        g.c = new PathFigureCollection();
        var h = new List$1(PolyLineSegment.$, 0);
        var i = 0;
        for (var j = 0; j < b; j++) {
            if (isNaN_(c(j)) || isNaN_(d(j))) {
                var k = j - i;
                if (k > 0) {
                    if (e == 1 || h.count == 0) {
                        var l = new PolyLineSegment();
                        h.add(l);
                    }
                    this.ui(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                }
                i = j + 1;
            }
        }
        if (e == 1 || h.count == 0) {
            var m = new PolyLineSegment();
            h.add(m);
        }
        this.ui(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
        var _loop_1 = function (n) {
            var o = h._inner[n];
            if (o._points.count > 0) {
                var p = ((function () {
                    var $ret = new PathFigure();
                    $ret.startPoint = o._points._inner[0];
                    return $ret;
                })());
                p._segments.add(o);
                g.c.add(p);
            }
        };
        for (var n = 0; n < h.count; n++) {
            _loop_1(n);
        }
    };
    ScatterLineSeries.prototype.uf = function (a, b, c, d, e, f) {
        var g = new List$1(Number_$type, 0);
        var h = d;
        var i = e;
        var j = i - h + 1;
        while (j > 0) {
            if (j <= 512) {
                Flattener.c(g, b, c, h, i, f);
                h = i + 1;
            }
            else {
                var k = h + 512 - 1;
                Flattener.c(g, b, c, h, k, f);
                h = k + 1;
            }
            j = i - h + 1;
        }
        return g;
    };
    ScatterLineSeries.prototype.ui = function (a, b, c, d, e, f) {
        if (c > -1) {
            var g = this.gk;
            var h = this.uf(new List$1(Number_$type, 0), d, e, b, c, g);
            var i = void 0;
            for (var j = 0; j < h.count; j++) {
                i = h.item(j);
                a.add({ $type: Point_$type, x: d(i), y: e(i) });
            }
        }
    };
    ScatterLineSeries.prototype.lt = function (a, b, c, d) {
        _super.prototype.lt.call(this, a, b, c, d);
        switch (b) {
            case ScatterLineSeries.$$p[0]:
                this.l7(false);
                this.le();
                break;
        }
    };
    ScatterLineSeries.$t = markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:ud:uk', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
}(ScatterBase));
export { ScatterLineSeries };

==> igniteui-react-charts-16.16.1.tgz: package/esm5/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { RectUtil } from "igniteui-react-core";
import { PolyLineSegment } from "igniteui-react-core";
import { PathFigure } from "igniteui-react-core";
import { PathFigureCollection } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { boxArray$1, arrayShallowClone } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeries, _super);
    function ScatterLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterLineSeries.$;
        _this.r3 = new ScatterFrame();
        _this.r5 = new ScatterFrame();
        _this.r1 = new ScatterFrame();
        var a = function (b, c, d) {
            var e = _this.ck.indexOf(b.a);
            if (e == -1 || e == 0) {
                return b;
            }
            var f = _this.ck.item(e - 1);
            var g;
            if (!((function () { var h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                return b;
            }
            return g;
        };
        _this.r3.o = a;
        _this.r5.o = a;
        _this.r1.o = a;
        return _this;
    }
    ScatterLineSeries.prototype.get_d1 = function () {
        return true;
    };
    ScatterLineSeries.prototype.bx = function () {
        return new ScatterLineSeriesView(this);
    };
    ScatterLineSeries.prototype.gu = function () {
        if (!isNaN_(this.gt)) {
            return _super.prototype.gu.call(this);
        }
        return Defaults.x;
    };
    ScatterLineSeries.prototype.ev = function (a, b) {
        if (this.qg(a, b)) {
            return true;
        }
        if (this.u3(a, b)) {
            return true;
        }
        return false;
    };
    ScatterLineSeries.prototype.u3 = function (a, b) {
        var c = this.b0;
        var d = c.dg;
        return this.ew(a, b, d.ak);
    };
    ScatterLineSeries.prototype.tx = function (a, b) {
        var _this = this;
        _super.prototype.tx.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.bv;
        var d = b.bu;
        var e = this.getEffectiveViewport1(b);
        var f = this.ft * this.ft;
        var g = 0;
        if (this.sd != null) {
            g = this.sd.count;
        }
        if (this.se != null) {
            g = Math.min(this.se.count, g);
        }
        var h = new ScalerParams(0, c, d, this.rx.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.rx.e, e);
            $ret.b = _this.gc();
            return $ret;
        })());
        var j = arrayShallowClone(this.sd.asArray());
        var k = arrayShallowClone(this.se.asArray());
        this.xAxis.hm(boxArray$1(j), 0, j.length, h);
        this.yAxis.hm(boxArray$1(k), 0, k.length, i);
        var l = d.top - 10;
        var m = d.bottom + 10;
        var n = d.left - 10;
        var o = d.right + 10;
        var p = ((function () {
            var $ret = new Clipper(1, n, m, o, l, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var q = 0; q < g;) {
            var r = q;
            ++q;
            if (g > this.sy) {
                while (q < g) {
                    var s = j[q] - j[r];
                    var t = k[q] - k[r];
                    var u = s * s + t * t;
                    if (u >= f) {
                        break;
                    }
                    ++q;
                }
                p.j(this.va(j, k, r, q - 1));
            }
            else {
                var v = new OwnedPoint();
                v.c = { $type: Point_$type, x: j[r], y: k[r] };
                v.a = this.ck.item(r);
                if (!a.u.containsKey(v.a)) {
                    a.u.addItem(v.a, v);
                }
            }
        }
        if (g > this.sy) {
            p.i = null;
        }
    };
    ScatterLineSeries.prototype.va = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a[c], y: b[c] };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a[h];
            f += b[h];
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterLineSeries.prototype.get_sl = function () {
        return true;
    };
    ScatterLineSeries.prototype.t8 = function (a, b) {
        b.c4(false);
        _super.prototype.t8.call(this, a, b);
        var c = this.getEffectiveViewport1(b);
        var d = new Rect(0, b.bu.left, b.bu.top, b.bu.width, b.bu.height);
        d = RectUtil.t(d, this.fu, this.fu);
        this.t1(a, new Clipper(0, d, false));
        var e = typeCast(ScatterLineSeriesView.$, b);
        this.sa.ax(this, this.sq(), runOn(this, this.rl));
        var f = false;
        var g = this.sa.b;
        if (g != null) {
            f = true;
        }
        if (f) {
            this.tt(-1, this.sd.count, b.q);
        }
        this.sa.ad(e.dg, true, false, true, false);
        this.u8(e.dg, a.m.count, function (h) { return a.m._inner[h].x; }, function (h) { return a.m._inner[h].y; }, this.u2, this.ft);
    };
    ScatterLineSeries.prototype.u8 = function (a, b, c, d, e, f) {
        var g = new PathGeometry();
        a.ak = g;
        g.c = new PathFigureCollection();
        var h = new List$1(PolyLineSegment.$, 0);
        var i = 0;
        for (var j = 0; j < b; j++) {
            if (isNaN_(c(j)) || isNaN_(d(j))) {
                var k = j - i;
                if (k > 0) {
                    if (e == 1 || h.count == 0) {
                        var l = new PolyLineSegment();
                        h.add(l);
                    }
                    this.u7(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                }
                i = j + 1;
            }
        }
        if (e == 1 || h.count == 0) {
            var m = new PolyLineSegment();
            h.add(m);
        }
        this.u7(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
        var _loop_1 = function (n) {
            var o = h._inner[n];
            if (o._points.count > 0) {
                var p = ((function () {
                    var $ret = new PathFigure();
                    $ret.startPoint = o._points._inner[0];
                    return $ret;
                })());
                p._segments.add(o);
                g.c.add(p);
            }
        };
        for (var n = 0; n < h.count; n++) {
            _loop_1(n);
        }
    };
    ScatterLineSeries.prototype.u4 = function (a, b, c, d, e, f) {
        var g = new List$1(Number_$type, 0);
        var h = d;
        var i = e;
        var j = i - h + 1;
        while (j > 0) {
            if (j <= 512) {
                Flattener.c(g, b, c, h, i, f);
                h = i + 1;
            }
            else {
                var k = h + 512 - 1;
                Flattener.c(g, b, c, h, k, f);
                h = k + 1;
            }
            j = i - h + 1;
        }
        return g;
    };
    ScatterLineSeries.prototype.u7 = function (a, b, c, d, e, f) {
        if (c > -1) {
            var g = !isNaN_(this.gt) ? f : 1;
            var h = this.u4(new List$1(Number_$type, 0), d, e, b, c, g);
            var i = void 0;
            for (var j = 0; j < h.count; j++) {
                i = h.item(j);
                a.add({ $type: Point_$type, x: d(i), y: e(i) });
            }
        }
    };
    ScatterLineSeries.prototype.l4 = function (a, b, c, d) {
        _super.prototype.l4.call(this, a, b, c, d);
        switch (b) {
            case ScatterLineSeries.$$p[0]:
                this.mi(false);
                this.lp();
                break;
        }
    };
    ScatterLineSeries.$t = markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:u2:u9', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
}(ScatterBase));
export { ScatterLineSeries };
